summaryrefslogtreecommitdiffstats
path: root/chrome/common/file_descriptor_set_posix.h
diff options
context:
space:
mode:
authoragl@chromium.org <agl@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-02-12 18:32:45 +0000
committeragl@chromium.org <agl@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-02-12 18:32:45 +0000
commitd0c0b1d9fa189387ec37d251fd6c5f05fad0f0fe (patch)
tree4120702c3383e5c6603886588bf85902bd41d1d9 /chrome/common/file_descriptor_set_posix.h
parent416478170d0dd41b071fdf4df1438786c581c03f (diff)
downloadchromium_src-d0c0b1d9fa189387ec37d251fd6c5f05fad0f0fe.zip
chromium_src-d0c0b1d9fa189387ec37d251fd6c5f05fad0f0fe.tar.gz
chromium_src-d0c0b1d9fa189387ec37d251fd6c5f05fad0f0fe.tar.bz2
POSIX: Rename DescriptorSet to FileDescriptorSet
This is just following up on a code review promise. git-svn-id: svn://svn.chromium.org/chrome/trunk/src@9676 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/common/file_descriptor_set_posix.h')
-rw-r--r--chrome/common/file_descriptor_set_posix.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/chrome/common/file_descriptor_set_posix.h b/chrome/common/file_descriptor_set_posix.h
index 1757648..342e6d9 100644
--- a/chrome/common/file_descriptor_set_posix.h
+++ b/chrome/common/file_descriptor_set_posix.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_COMMON_DESCRIPTOR_SET_POSIX_H_
-#define CHROME_COMMON_DESCRIPTOR_SET_POSIX_H_
+#ifndef CHROME_COMMON_FILE_DESCRIPTOR_SET_POSIX_H_
+#define CHROME_COMMON_FILE_DESCRIPTOR_SET_POSIX_H_
#include <vector>
@@ -12,14 +12,14 @@
#include "base/ref_counted.h"
// -----------------------------------------------------------------------------
// A DescriptorSet is an ordered set of POSIX file descriptors. These are
// associated with IPC messages so that descriptors can be transmitted over a
// UNIX domain socket.
// -----------------------------------------------------------------------------
-class DescriptorSet : public base::RefCountedThreadSafe<DescriptorSet> {
+class FileDescriptorSet : public base::RefCountedThreadSafe<FileDescriptorSet> {
public:
- DescriptorSet();
- ~DescriptorSet();
+ FileDescriptorSet();
+ ~FileDescriptorSet();
// This is the maximum number of descriptors per message. We need to know this
// because the control message kernel interface has to be given a buffer which
@@ -28,7 +28,7 @@ class DescriptorSet : public base::RefCountedThreadSafe<DescriptorSet> {
// lost.
//
// In debugging mode, it's a fatal error to try and add more than this number
// of descriptors to a DescriptorSet.
enum {
MAX_DESCRIPTORS_PER_MESSAGE = 4,
};
@@ -102,7 +102,7 @@ class DescriptorSet : public base::RefCountedThreadSafe<DescriptorSet> {
// can check that they are read in order.
mutable unsigned consumed_descriptor_highwater_;
- DISALLOW_COPY_AND_ASSIGN(DescriptorSet);
+ DISALLOW_COPY_AND_ASSIGN(FileDescriptorSet);
};
-#endif // CHROME_COMMON_FILE_DESCRIPTOR_POSIX_H_
+#endif // CHROME_COMMON_FILE_DESCRIPTOR_SET_POSIX_H_
@@ -12,14 +12,14 @@
#include "base/ref_counted.h"
// -----------------------------------------------------------------------------
-// A DescriptorSet is an ordered set of POSIX file descriptors. These are
+// A FileDescriptorSet is an ordered set of POSIX file descriptors. These are
// associated with IPC messages so that descriptors can be transmitted over a
// UNIX domain socket.
@@ -28,7 +28,7 @@ class DescriptorSet : public base::RefCountedThreadSafe<DescriptorSet> {
//
// In debugging mode, it's a fatal error to try and add more than this number
- // of descriptors to a DescriptorSet.
+ // of descriptors to a FileDescriptorSet.
enum {
MAX_DESCRIPTORS_PER_MESSAGE = 4,